from copy import copy

import pandas as pd
from idmtools.core.platform_factory import Platform
from idmtools.entities.experiment import Experiment


def process_outpath(sim):
    outpath = sim.get_platform_object().hpc_jobs[0].working_directory.replace('internal.idm.ctr', 'mnt')
    outpath = outpath.replace('\\', '/')
    outpath = outpath.replace('IDM2', 'idm2')
    return outpath

def get_sim_map(experiment_id, platform=None):
    if platform is None:
        platform = Platform("SLURM")
    exp = Experiment.from_id(experiment_id, children=False)
    exp.simulations = platform.get_children(exp.id, exp.item_type, children=["tags", "configuration", "files", "hpc_jobs"])

    dict_list = []

    for simulation in exp.simulations:
        sim_data_dict = copy(dict(simulation.tags))
        sim_data_dict["sim_id"] = simulation.id
        sim_data_dict["outpath"] = process_outpath(simulation)

        dict_list.append(sim_data_dict)


    df = pd.DataFrame(dict_list)
    return df
