# def run_analyzer_locally(analyzer_list, analyzer_args):
#     platform =
from idmtools.analysis.analyze_manager import AnalyzeManager
from idmtools.analysis.platform_anaylsis import PlatformAnalysis
from idmtools.core import ItemType
from idmtools.core.platform_factory import Platform
from idmtools_platform_comps.utils.download.download import DownloadWorkItem

from jsuresh_helpers.analyzers.sim_endpoint import SimEndpoint


def run_analyzer_as_ssmt(experiment_id,
                         analyzers,
                         analyzer_args,
                         analysis_name="SSMT analysis"):
    platform = Platform("SLURM")
    analysis = PlatformAnalysis(
        platform=platform,
        # platform=Platform("SLURM"),
        experiment_ids=[experiment_id],
        analyzers=analyzers,
        analyzers_args=analyzer_args,
        analysis_name=analysis_name,
    )
    analysis.analyze(check_status=True)
    wi = analysis.get_work_item()
    print(wi)

    # Download the actual output (code snippet from Clinton 1/3/22)
    dl_wi = DownloadWorkItem(related_work_items=[wi.id],
                             file_patterns=["*.csv"],
                             delete_after_download=False,
                             extract_after_download=True,
                             verbose=True)
    dl_wi.run(wait_on_done=True, platform=platform)


def run_analyzer_locally(experiment_id,
                         analyzers,
                         analyzer_args,
                         max_items=None):
    analyzers_with_arguments_input = []
    for i in range(len(analyzers)):
        analyzers_with_arguments_input.append(analyzers[i](**analyzer_args[i]))

    manager = AnalyzeManager(platform=Platform("SLURM"),
                             ids=[(experiment_id, ItemType.EXPERIMENT)],
                             analyzers=analyzers_with_arguments_input,
                             max_items=max_items #for debugging/speed, can set max_items=1
                             )
    # elif sim_id is not None:
    #     manager = AnalyzeManager(ids=[(sim_id, ItemType.SIMULATION)], analyzers=analyzers_with_arguments_input)
    manager.analyze()

    # Test to see if we can get the output afterwards
    results = [x.results for x in manager.analyzers]
    print(results)
    return results


if __name__ == '__main__':
    experiment_id = "5e7e2505-9a5f-ec11-a9f1-9440c9be2c51"
    analyzers = [SimEndpoint]
    analyzer_args = [{"save_file": "test.csv"}]

    # run_analyzer_locally(experiment_id, analyzers, analyzer_args)
    run_analyzer_as_ssmt(experiment_id=experiment_id, analyzers=analyzers, analyzer_args=analyzer_args)