import numpy as np
import pandas as pd
import matplotlib.pyplot as plt

from jsuresh_helpers.analyzers import run_analyzer_and_return_output
from jsuresh_helpers.endpoints_and_elimination import run_endpoint_analyzers_and_save_output


def find_representative_seed(exp_id, agg="median", on="funest", savefig=False, force_analyze=False, **kwargs):
    # Find Run_Number that is most representative of runs in an experiment

    # Get dataframe of transmission metrics at end of simulation:
    df = run_endpoint_analyzers_and_save_output(exp_id, years_to_include=54, savefile=False, force_analyze=force_analyze)
    if "year" in kwargs:
        df = df[df["year"]==kwargs["year"]].reset_index(drop=True)

    foo = df.groupby(on).agg(agg).reset_index()

    # Find difference of each run from the center
    merge_left = df[["funest", "Run_Number", "EIR", "cases", "avg_RDT_prev"]]
    merge_right = foo[["funest", "EIR", "cases", "avg_RDT_prev"]].rename(
        columns={"EIR": "EIR_{}".format(agg),
                 "cases": "cases_{}".format(agg),
                 "avg_RDT_prev": "avg_RDT_prev_{}".format(agg)})

    bar = merge_left.merge(merge_right, on=on)
    bar["diff_EIR"] = np.abs(bar["EIR"] - bar["EIR_median"]) / bar["EIR_median"]
    bar["diff_cases"] = np.abs(bar["cases"] - bar["cases_median"]) / bar["cases_median"]
    bar["diff_avg_RDT_prev"] = np.abs(bar["avg_RDT_prev"] - bar["avg_RDT_prev_median"]) / bar["avg_RDT_prev_median"]
    bar["diff"] = bar["diff_EIR"] + bar["diff_cases"] + bar["diff_avg_RDT_prev"]


    # Find run number with minimum difference:
    dict_list = []

    for f, sdf in bar.groupby(on):
        diff = np.array(sdf["diff"])
        seed = np.array(sdf["Run_Number"])
        min_diff_seed = seed[np.argmin(diff)]

        dict_list.append({on: f,
                          "Run_Number": min_diff_seed})

    best_seeds_df = pd.DataFrame(dict_list)


    if savefig:
        plt.figure()
        plt.scatter(df[on], df["EIR"])
        plt.scatter(foo[on], foo["EIR"])

        # foo.idxmin(axis=0, skipna=True)
        # plt.scatter(bar[on],)

        plt.savefig("test_image.png")


    return best_seeds_df


if __name__=="__main__":
    test = find_representative_seed("776826a6-de13-eb11-a2c7-c4346bcb1553", savefig=True, force_analyze=False, year=50)
    print(test)
    test.to_csv("variable_nodesize_best_burnin_test.csv", index=False)