from emodpy_malaria.interventions.usage_dependent_bednet import add_scheduled_usage_dependent_bednet, \
    add_triggered_usage_dependent_bednet

default_bednet_age_usage = {'youth_cov': 0.65,
                            'youth_min_age': 5,
                            'youth_max_age': 20}

default_itn_discard_config = {
    "Expiration_Period_Distribution": "DUAL_EXPONENTIAL_DISTRIBUTION",
    "Expiration_Period_Mean_1": 260,
    "Expiration_Period_Mean_2": 2106,
    "Expiration_Period_Proportion_1": 0.6
}


def add_bednets_for_population_and_births(campaign,
                                          coverage,
                                          start_day=1,
                                          seasonal_dependence=None,
                                          discard_config=None,
                                          age_dependence=default_bednet_age_usage,
                                          include_birthnets=True,
                                          birthnet_listening_duration=-1,
                                          killing_initial_effect=0.6,
                                          killing_box_duration=0,
                                          killing_decay_time_constant=1460.,
                                          blocking_initial_effect=0.9,
                                          blocking_box_duration=0,
                                          blocking_decay_time_constant=730.):

    if seasonal_dependence is None:
        seasonal_dependence = {}

    regular_bednets_event = add_scheduled_usage_dependent_bednet(campaign=campaign,
                                                                 start_day=start_day,
                                                                 demographic_coverage=coverage,
                                                                 age_dependence=age_dependence,
                                                                 seasonal_dependence=seasonal_dependence,
                                                                 discard_config=discard_config,
                                                                 killing_initial_effect=killing_initial_effect, #explicitly putting in killing/blocking even though these are defaults, in case UDBednet defaults change down the road
                                                                 killing_box_duration=killing_box_duration,
                                                                 killing_decay_time_constant=killing_decay_time_constant,
                                                                 blocking_initial_effect=blocking_initial_effect,
                                                                 blocking_box_duration=blocking_box_duration,
                                                                 blocking_decay_time_constant=blocking_decay_time_constant)

    if include_birthnets:
        birth_bednets_event = add_triggered_usage_dependent_bednet(campaign=campaign,
                                                                   trigger_condition_list=["Births"],
                                                                   start_day=start_day,
                                                                   demographic_coverage=coverage,
                                                                   age_dependence=age_dependence,
                                                                   seasonal_dependence=seasonal_dependence,
                                                                   discard_config=discard_config,
                                                                   listening_duration=birthnet_listening_duration,
                                                                   killing_initial_effect=killing_initial_effect,
                                                                   # explicitly putting in killing/blocking even though these are defaults, in case UDBednet defaults change down the road
                                                                   killing_box_duration=killing_box_duration,
                                                                   killing_decay_time_constant=killing_decay_time_constant,
                                                                   blocking_initial_effect=blocking_initial_effect,
                                                                   blocking_box_duration=blocking_box_duration,
                                                                   blocking_decay_time_constant=blocking_decay_time_constant)