import pandas as pd
import numpy as np
import json

def round_to_n_digits(x, n=2):
    return np.round(x*10**n)/10**n


def isfloat(value):
    try:
        float(value)
        return True
    except ValueError:
        return False


def load_inset(outpath, channel, chart_name="InsetChart.json"):
    fname = outpath + chart_name
    with open(fname) as fin:
        data = json.loads(fin.read())
        return data['Channels'][channel]['Data']


def window_sum(x, i_start, i_end, window_size=30):
    windowed_x = np.zeros(i_end - i_start)
    for j in np.arange(len(windowed_x)):
        windowed_x[j] = np.sum(x[i_start + j - int(window_size / 2):i_start + j + int(window_size / 2)])
    return windowed_x


def get_most_common_string_in_list(l):
    counts = {}

    for s in l:
        if s in counts:
            counts[s] += 1
        else:
            counts[s] = 1

    counts_names = list(counts.keys())
    counts_vals = list(counts.values())

    return counts_names[np.argmax(counts_vals)]

# fixme Add SSMT stuff?

def average_over_duplicates(x, y):
    x_unique, index, counts = np.unique(x, return_index=True, return_counts=True)
    if len(x_unique) == len(x):
        return x, y
    else:
        duplicated = counts > 1
        not_duplicated = counts == 1

        x_not_duplicated = x[index[not_duplicated]]
        y_not_duplicated = y[index[not_duplicated]]

        x_duplicated = np.array([])
        y_duplicated = np.array([])
        for xx in x[index[duplicated]]:
            x_duplicated = np.append(x_duplicated, xx)
            yy = y[x == xx]
            y_duplicated = np.append(y_duplicated, np.mean(yy))

        new_x = np.append(x_duplicated, x_not_duplicated)
        new_y = np.append(y_duplicated, y_not_duplicated)

        argsort_x = np.argsort(new_x)
        new_x = new_x[argsort_x]
        new_y = new_y[argsort_x]

        return new_x, new_y


def add_suffix_to_all_columns(df, suffix, ignore_columns=[]):
    dd = {}
    for column in df.columns:
        if column not in ignore_columns:
            dd[column] = column + suffix

    return df.rename(columns=dd)


def merge_and_rename_shared_column(df1, df2, column_to_merge_on, shared_column, rename_df1_column, rename_df2_column,
                                   how="inner"):
    columns_to_keep = [column_to_merge_on, shared_column]

    hold1 = df1[columns_to_keep].rename(columns={shared_column: rename_df1_column})
    hold2 = df2[columns_to_keep].rename(columns={shared_column: rename_df2_column})

    df_merged = hold1.merge(hold2, on=column_to_merge_on, how=how).reset_index(drop=True)

    return df_merged


def load_report(fname, channel):
    with open(fname) as fin:
        data = json.loads(fin.read())
        return data['Channels'][channel]['Data']

# def basic_workspace_imports():
#     import numpy as np
#     import pandas as pd
#     import matplotlib
#     matplotlib.rcParams["pdf.fonttype"] = 42
#     import matplotlib.pyplot as plt
#     import seaborn as sns


# is_sorted = lambda x: (np.diff(x)>=0).all()
def is_sorted(x):
    return (np.diff(x) >= 0).all()


def load_csv_into_dictionary(csv_filename):
    df = pd.read_csv(csv_filename, header=None)
    return_dict = {}

    for i in range(len(df)):
        row = list(df.iloc[i])
        param_name = row[0]
        param_value = try_to_convert_string_to_numeric(row[1])
        return_dict[param_name] = param_value

    return return_dict


def save_dictionary_to_csv(save_dict, csv_filename):
    df = pd.Series(save_dict).to_frame()
    # pd.to_numeric(df, errors='ignore') # Make sure numbers are numeric, not strings
    df.to_csv(csv_filename, header=False)


def try_to_convert_string_to_numeric(x):
    # Try to convert to int.  If that doesn't work, try float.  If that doesn't work, return original string
    x_new = None

    try:
        x_new = np.int(x)
    except ValueError:
        pass

    if x_new == None:
        try:
            x_new = np.float(x)
        except ValueError:
            pass

    if x_new == None:
        return x
    else:
        return x_new





def remove_duplicate_columns(df):
    columns_to_keep = []
    for c in df.columns:
        if "_duplicated" not in c:
            columns_to_keep.append(c)
    return df[columns_to_keep]
